# coding: utf-8

"""
    Connect API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from trinsic_api.models.list_sessions_response import ListSessionsResponse

class TestListSessionsResponse(unittest.TestCase):
    """ListSessionsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ListSessionsResponse:
        """Test ListSessionsResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ListSessionsResponse`
        """
        model = ListSessionsResponse()
        if include_optional:
            return ListSessionsResponse(
                sessions = [
                    trinsic_api.models.session.Session(
                        id = '678c1ff6-2178-49e7-81d2-548afb6f85ec', 
                        state = null, 
                        fail_code = null, 
                        verification = null, 
                        disclosed_fields = null, 
                        created = 1722526411, 
                        updated = 1722526722, )
                    ],
                total = 101,
                more = True
            )
        else:
            return ListSessionsResponse(
                sessions = [
                    trinsic_api.models.session.Session(
                        id = '678c1ff6-2178-49e7-81d2-548afb6f85ec', 
                        state = null, 
                        fail_code = null, 
                        verification = null, 
                        disclosed_fields = null, 
                        created = 1722526411, 
                        updated = 1722526722, )
                    ],
                total = 101,
                more = True,
        )
        """

    def testListSessionsResponse(self):
        """Test ListSessionsResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
