# coding: utf-8

"""
    Connect API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from trinsic_api.models.create_session_response import CreateSessionResponse

class TestCreateSessionResponse(unittest.TestCase):
    """CreateSessionResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CreateSessionResponse:
        """Test CreateSessionResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CreateSessionResponse`
        """
        model = CreateSessionResponse()
        if include_optional:
            return CreateSessionResponse(
                session = trinsic_api.models.session.Session(
                    id = '678c1ff6-2178-49e7-81d2-548afb6f85ec', 
                    state = null, 
                    fail_code = null, 
                    verification = null, 
                    disclosed_fields = null, 
                    created = 1722526411, 
                    updated = 1722526722, ),
                launch_url = 'https://api.trinsic.id/api/session/launch?clientToken=...'
            )
        else:
            return CreateSessionResponse(
                session = trinsic_api.models.session.Session(
                    id = '678c1ff6-2178-49e7-81d2-548afb6f85ec', 
                    state = null, 
                    fail_code = null, 
                    verification = null, 
                    disclosed_fields = null, 
                    created = 1722526411, 
                    updated = 1722526722, ),
        )
        """

    def testCreateSessionResponse(self):
        """Test CreateSessionResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
