# coding: utf-8

"""
    Connect API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from trinsic_api.api.network_api import NetworkApi


class TestNetworkApi(unittest.TestCase):
    """NetworkApi unit test stubs"""

    def setUp(self) -> None:
        self.api = NetworkApi()

    def tearDown(self) -> None:
        pass

    def test_identity_lookup(self) -> None:
        """Test case for identity_lookup

        Lookup Identity
        """
        pass

    def test_list_providers(self) -> None:
        """Test case for list_providers

        List Identity Providers
        """
        pass


if __name__ == '__main__':
    unittest.main()
