# coding: utf-8

"""
    Connect API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from trinsic_api.models.address import Address
from typing import Optional, Set
from typing_extensions import Self

class PersonData(BaseModel):
    """
    Identity information for the individual being verified
    """ # noqa: E501
    given_name: Optional[StrictStr] = Field(default=None, description="Given (first) name of the individual", alias="givenName")
    family_name: Optional[StrictStr] = Field(default=None, description="Family (last) name of the individual", alias="familyName")
    middle_name: Optional[StrictStr] = Field(default=None, description="Middle name of the individual", alias="middleName")
    full_name: Optional[StrictStr] = Field(default=None, description="The individual's full name as a single string.                Useful for names which do not fit into a \"first middle last\" structure.", alias="fullName")
    nationality: Optional[StrictStr] = None
    gender: Optional[StrictStr] = None
    phone_number: Optional[StrictStr] = Field(default=None, alias="phoneNumber")
    address: Optional[Address] = Field(default=None, description="Address information for an individual")
    date_of_birth: Optional[StrictStr] = Field(default=None, alias="dateOfBirth")
    __properties: ClassVar[List[str]] = ["givenName", "familyName", "middleName", "fullName", "nationality", "gender", "phoneNumber", "address", "dateOfBirth"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PersonData from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of address
        if self.address:
            _dict['address'] = self.address.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PersonData from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "givenName": obj.get("givenName"),
            "familyName": obj.get("familyName"),
            "middleName": obj.get("middleName"),
            "fullName": obj.get("fullName"),
            "nationality": obj.get("nationality"),
            "gender": obj.get("gender"),
            "phoneNumber": obj.get("phoneNumber"),
            "address": Address.from_dict(obj["address"]) if obj.get("address") is not None else None,
            "dateOfBirth": obj.get("dateOfBirth")
        })
        return _obj


