# coding: utf-8

"""
    Connect API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from trinsic_api.models.session import Session

class TestSession(unittest.TestCase):
    """Session unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Session:
        """Test Session
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Session`
        """
        model = Session()
        if include_optional:
            return Session(
                id = '678c1ff6-2178-49e7-81d2-548afb6f85ec',
                state = 'IdvCreated',
                fail_code = 'SessionFailNone',
                verification = trinsic_api.models.verification.Verification(
                    provider = '', 
                    fail_code = null, ),
                disclosed_fields = trinsic_api.models.disclosed_fields.DisclosedFields(
                    id_number = True, 
                    given_name = True, 
                    family_name = True, 
                    address = True, 
                    date_of_birth = True, 
                    country = True, 
                    issue_date = True, 
                    expiration_date = True, 
                    document_front = True, 
                    document_back = True, 
                    document_portrait = True, 
                    selfie = True, ),
                created = 1722526411,
                updated = 1722526722
            )
        else:
            return Session(
                id = '678c1ff6-2178-49e7-81d2-548afb6f85ec',
                state = 'IdvCreated',
                verification = trinsic_api.models.verification.Verification(
                    provider = '', 
                    fail_code = null, ),
                disclosed_fields = trinsic_api.models.disclosed_fields.DisclosedFields(
                    id_number = True, 
                    given_name = True, 
                    family_name = True, 
                    address = True, 
                    date_of_birth = True, 
                    country = True, 
                    issue_date = True, 
                    expiration_date = True, 
                    document_front = True, 
                    document_back = True, 
                    document_portrait = True, 
                    selfie = True, ),
                created = 1722526411,
                updated = 1722526722,
        )
        """

    def testSession(self):
        """Test Session"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
