# coding: utf-8

"""
    Connect API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from trinsic_api.models.identity_data import IdentityData

class TestIdentityData(unittest.TestCase):
    """IdentityData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> IdentityData:
        """Test IdentityData
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `IdentityData`
        """
        model = IdentityData()
        if include_optional:
            return IdentityData(
                originating_provider_id = '',
                person = trinsic_api.models.person_data.PersonData(
                    given_name = 'John', 
                    family_name = 'Doe', 
                    middle_name = 'Jacob', 
                    full_name = 'John Jacob de Doe', 
                    nationality = '', 
                    gender = '', 
                    phone_number = '', 
                    address = null, 
                    date_of_birth = '', ),
                document = trinsic_api.models.document_data.DocumentData(
                    type = '', 
                    number = '', 
                    issue_date = '', 
                    expiration_date = '', 
                    issuing_country = '', 
                    issuing_authority = '', ),
                attachment_access_keys = trinsic_api.models.attachment_access_keys.AttachmentAccessKeys(
                    selfie = '', 
                    document_front = '', 
                    document_back = '', 
                    document_portrait = '', )
            )
        else:
            return IdentityData(
        )
        """

    def testIdentityData(self):
        """Test IdentityData"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
