# coding: utf-8

"""
    Connect API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from trinsic_api.api.sessions_api import SessionsApi


class TestSessionsApi(unittest.TestCase):
    """SessionsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SessionsApi()

    def tearDown(self) -> None:
        pass

    def test_cancel_session(self) -> None:
        """Test case for cancel_session

        Cancel Session
        """
        pass

    def test_create_session(self) -> None:
        """Test case for create_session

        Create Session
        """
        pass

    def test_get_session(self) -> None:
        """Test case for get_session

        Get Session
        """
        pass

    def test_get_session_result(self) -> None:
        """Test case for get_session_result

        Get Session Results
        """
        pass

    def test_list_sessions(self) -> None:
        """Test case for list_sessions

        List Sessions
        """
        pass

    def test_redact_session(self) -> None:
        """Test case for redact_session

        Redact Session
        """
        pass


if __name__ == '__main__':
    unittest.main()
