# coding: utf-8

"""
    Connect API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from trinsic_api.models.person_data import PersonData

class TestPersonData(unittest.TestCase):
    """PersonData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PersonData:
        """Test PersonData
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PersonData`
        """
        model = PersonData()
        if include_optional:
            return PersonData(
                given_name = 'John',
                family_name = 'Doe',
                middle_name = 'Jacob',
                full_name = 'John Jacob de Doe',
                nationality = '',
                gender = '',
                phone_number = '',
                address = trinsic_api.models.address.Address(
                    line1 = '', 
                    line2 = '', 
                    line3 = '', 
                    city = '', 
                    state = '', 
                    postal_code = '', 
                    country = '', 
                    full_address = '', ),
                date_of_birth = ''
            )
        else:
            return PersonData(
        )
        """

    def testPersonData(self):
        """Test PersonData"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
